@@ -22,23 +22,23 @@ class AnalogImpedance(DwfDevice_SubAPI):
     # pylint: disable=too-many-public-methods
 
     def reset(self) -> None:
-        """Reset the Analog Impedance measurement instrument.
+        """Reset the Analog Impedance measurement functionality.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: There was an error while executing the reset operation.
         """
         result = self.lib.FDwfAnalogImpedanceReset(self.hdwf)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def configure(self, start: bool) -> None:
-        """Configure the AnalogImpedance measurement.
+        """Configure the AnalogImpedance measurement, and optionally start a measurement.
 
         Parameters:
             start (bool): Whether to start the measurement.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: There was an error while executing the configure operation.
         """
         result = self.lib.FDwfAnalogImpedanceConfigure(self.hdwf, int(start))
         if result != RESULT_SUCCESS:
@@ -48,10 +48,10 @@ class AnalogImpedance(DwfDevice_SubAPI):
         """Return the status of the AnalogImpedance measurement.
 
         Returns:
-            DwfState: Status of the measurement.
+            DwfState: The status of the measurement.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: There was an error while executing the status operation.
         """
         c_status = typespec_ctypes.DwfState()
         result = self.lib.FDwfAnalogImpedanceStatus(self.hdwf, c_status)
@@ -64,13 +64,13 @@ class AnalogImpedance(DwfDevice_SubAPI):
         """Set measurement mode.
 
         Parameters:
-            mode (int): Measurement mode.
+            mode (int): The measurement mode.
 
                 The following modes are defined:
 
-                * 0 W1-C1-DUT-C2-R-GND
-                * 1 W1-C1-R-C2-DUT-GND
-                * 8 Impedance Analyzer for the Analog Discovery
+                * 0: W1-C1-DUT-C2-R-GND
+                * 1: W1-C1-R-C2-DUT-GND
+                * 8: Impedance Analyzer for the Analog Discovery
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -83,13 +83,13 @@ class AnalogImpedance(DwfDevice_SubAPI):
         """Get measurement mode.
 
         Returns:
-            int: measurement mode.
+            int: The measurement mode.
 
             The following modes are defined:
 
-            * 0 W1-C1-DUT-C2-R-GND
-            * 1 W1-C1-R-C2-DUT-GND
-            * 8 Impedance Analyzer for the Analog Discovery
+            * 0: W1-C1-DUT-C2-R-GND
+            * 1: W1-C1-R-C2-DUT-GND
+            * 8: Impedance Analyzer for the Analog Discovery
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -105,7 +105,7 @@ class AnalogImpedance(DwfDevice_SubAPI):
         """Set reference load value, in Ohms.
 
         Parameters:
-            reference: Reference load, in Ohms.
+            reference (float): The reference load, in Ohms.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -118,7 +118,7 @@ class AnalogImpedance(DwfDevice_SubAPI):
         """Get reference load value, in Ohms.
 
         Returns:
-            float: Reference load, in Ohms.
+            float: The reference load, in Ohms.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -131,10 +131,10 @@ class AnalogImpedance(DwfDevice_SubAPI):
         return reference
 
     def frequencySet(self, frequency: float) -> None:
-        """Set frequency, in Hz
+        """Set source frequency, in Hz
 
         Parameters:
-            frequency: Frequency, in Hz.
+            frequency (float): The source frequency, in Hz.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -144,10 +144,10 @@ class AnalogImpedance(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def frequencyGet(self) -> float:
-        """Get frequency, in Hz.
+        """Get source frequency, in Hz.
 
         Returns:
-            float: Frequency, in Hz.
+            float: The source frequency, in Hz.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -160,10 +160,10 @@ class AnalogImpedance(DwfDevice_SubAPI):
         return frequency
 
     def amplitudeSet(self, amplitude: float) -> None:
-        """Set amplitude value, in Volts.
+        """Set source amplitude value, in Volts.
 
         Parameters:
-            amplitude: Amplitude, in Volts.
+            amplitude (float): The source amplitude, in Volts.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -173,10 +173,10 @@ class AnalogImpedance(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def amplitudeGet(self) -> float:
-        """Get amplitude, in Volts.
+        """Get source amplitude, in Volts.
 
         Returns:
-            float: Amplitude, in Volts.
+            float: The source amplitude, in Volts.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -189,10 +189,10 @@ class AnalogImpedance(DwfDevice_SubAPI):
         return amplitude
 
     def offsetSet(self, offset: float) -> None:
-        """Set offset, in Volts.
+        """Set source offset, in Volts.
 
         Parameters:
-            offset: Offset, in Volts.
+            offset (float): The source offset, in Volts.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -202,10 +202,10 @@ class AnalogImpedance(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def offsetGet(self) -> float:
-        """Get offset, in Volts.
+        """Get source offset, in Volts.
 
         Returns:
-            float: Offset, in Volts.
+            float: The source offset, in Volts.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -221,8 +221,8 @@ class AnalogImpedance(DwfDevice_SubAPI):
         """Set probe parameters.
 
         Parameters:
-            resistance: Probe resistance, in Ohms.
-            capacitance: Probe capacitance, in Farads.
+            resistance (float): The probe resistance, in Ohms.
+            capacitance (float): The probe capacitance, in Farads.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -236,7 +236,7 @@ class AnalogImpedance(DwfDevice_SubAPI):
 
         Returns:
             Tuple[float, float]:
-                A two-element tuple: probe resistance, in Ohms, and probe capacity, in Farads.
+                A two-element tuple: the probe resistance, in Ohms, and the probe capacity, in Farads.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -251,7 +251,7 @@ class AnalogImpedance(DwfDevice_SubAPI):
         return (resistance, capacity)
 
     def periodSet(self, period: int) -> None:
-        """Set measurement period.
+        """Set the measurement period.
 
         Parameters:
             period (int): The measurement period.
@@ -264,7 +264,7 @@ class AnalogImpedance(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def periodGet(self) -> int:
-        """Get measurement period.
+        """Get the measurement period.
 
 
         Returns:
@@ -281,7 +281,7 @@ class AnalogImpedance(DwfDevice_SubAPI):
         return period
 
     def compReset(self) -> None:
-        """Reset the computation.
+        """Reset the measurement computation.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -293,13 +293,13 @@ class AnalogImpedance(DwfDevice_SubAPI):
 
     def compSet(self, open_resistance: float, open_reactance: float,
                 short_resistance: float, short_reactance: float) -> None:
-        """Set computation parameters.
+        """Set the measurement computation parameters.
 
         Parameters:
-            open_resistance (float): Open-circuit resistance, in Ohms.
-            open_reactance (float): Open-circuit reactance, in Ohms.
-            short_resistance (float): Short-circuit resistance, in Ohms.
-            short_reactance (float): Short-circuit reactance, in Ohms.
+            open_resistance (float): The open-circuit resistance, in Ohms.
+            open_reactance (float): The open-circuit reactance, in Ohms.
+            short_resistance (float): The short-circuit resistance, in Ohms.
+            short_reactance (float): The short-circuit reactance, in Ohms.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -314,11 +314,11 @@ class AnalogImpedance(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def compGet(self) -> Tuple[float, float, float, float]:
-        """Get computation parameters.
+        """Get the measurement computation parameters.
 
         Returns:
-            Tuple[float, float, float, float]: the open-circuit resistance, open-circuit reactance,
-            short-circuit resistance, short-circuit reactance (all in Ohms).
+            Tuple[float, float, float, float]: The open-circuit resistance, open-circuit reactance,
+            short-circuit resistance, and short-circuit reactance (all in Ohms).
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -342,13 +342,13 @@ class AnalogImpedance(DwfDevice_SubAPI):
         return (open_resistance, open_reactance, short_resistance, short_reactance)
 
     def statusInput(self, channel_index: int) -> Tuple[float, float]:
-        """Get input measurement status.
+        """Get the input measurement status.
 
         Parameters:
             channel_index(int): The channel for which to get gain and phase information.
 
         Returns:
-            Tuple[float, float]: The gain and phase (radians) information of the current measurement.
+            Tuple[float, float]: The gain and phase (in radians) of the current measurement.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -367,7 +367,7 @@ class AnalogImpedance(DwfDevice_SubAPI):
         return (gain, radian)
 
     def statusMeasure(self, measure: DwfAnalogImpedance) -> float:
-        """Retrieve analog impedance measurement status value.
+        """Retrieve the measurement status value.
 
         Parameters:
             measure (DwfAnalogImpedance): The quantity to measure.
