@@ -53,8 +53,8 @@ class AnalogIO(DwfDevice_SubAPI):
         The following status functions will return the information that was read from the device
         when this function was last called.
 
-        Note that this method does not return a value, since the |AnalogIO| functionality is not
-        driven by a state machine.
+        Note that the |AnalogIO| functionality is not managed by a state machine,
+        so this method does not return a value.
 
         Raises:
             DwfLibraryError: There was an error while executing the status operation.
@@ -263,7 +263,8 @@ class AnalogIO(DwfDevice_SubAPI):
             node_index (int): The node from which we want to get the currently configured value.
 
         Returns:
-            Tuple[float, float, int]: the minimum and maximum values for the specified node's value, and the number of resolution steps.
+            Tuple[float, float, int]: the minimum and maximum values for the specified node's value,
+            and the number of resolution steps.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -332,7 +333,8 @@ class AnalogIO(DwfDevice_SubAPI):
             node_index (int): The node from which we want to get status information.
 
         Returns:
-            Tuple[float, float, int]: the minimum and maximum values for the specified node, and the number of resolution steps.
+            Tuple[float, float, int]: the minimum and maximum values for the specified node,
+            and the number of resolution steps.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
