@@ -20,7 +20,7 @@ class DigitalCan(DwfDevice_SubAPI):
     """
 
     def reset(self) -> None:
-        """Reset the digital-CAN protocol functionality.
+        """Reset the CAN bus protocol functionality.
 
         Raises:
             DwfLibraryError: There was an error while executing the reset operation.
